==> hadoop-common-2.7.5.0-javadoc.jar: native/CMakeFiles/hadoop.dir/cmake_clean.cmake <==
FILE(REMOVE_RECURSE
  "CMakeFiles/hadoop.dir/main/native/src/exception.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/lz4/Lz4Compressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/lz4/Lz4Decompressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/lz4/lz4.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/lz4/lz4hc.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/snappy/SnappyCompressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/snappy/SnappyDecompressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/crypto/OpensslCipher.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/crypto/random/OpensslSecureRandom.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/zlib/ZlibCompressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/zlib/ZlibDecompressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/bzip2/Bzip2Compressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/bzip2/Bzip2Decompressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/nativeio/NativeIO.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/nativeio/errno_enum.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/nativeio/file_descriptor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/nativeio/SharedFileDescriptorFactory.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/net/unix/DomainSocket.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/net/unix/DomainSocketWatcher.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/security/JniBasedUnixGroupsMapping.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/security/JniBasedUnixGroupsNetgroupMapping.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/security/hadoop_group_info.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/security/hadoop_user_info.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/util/NativeCodeLoader.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/util/NativeCrc32.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/util/bulk_crc32.c.o"
  "target/usr/local/lib/libhadoop.pdb"
  "target/usr/local/lib/libhadoop.so"
  "target/usr/local/lib/libhadoop.so.1.0.0"
)

# Per-language clean rules from dependency scanning.
FOREACH(lang C)
  INCLUDE(CMakeFiles/hadoop.dir/cmake_clean_${lang}.cmake OPTIONAL)
ENDFOREACH(lang)

==> hadoop-common-2.10.1-javadoc.jar: native/CMakeFiles/hadoop.dir/cmake_clean.cmake <==
file(REMOVE_RECURSE
  "CMakeFiles/hadoop.dir/main/native/src/exception.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/lz4/Lz4Compressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/lz4/Lz4Decompressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/lz4/lz4.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/lz4/lz4hc.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/snappy/SnappyCompressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/snappy/SnappyDecompressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/zstd/ZStandardCompressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/zstd/ZStandardDecompressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/crypto/OpensslCipher.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/crypto/random/OpensslSecureRandom.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/zlib/ZlibCompressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/zlib/ZlibDecompressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/bzip2/Bzip2Compressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/compress/bzip2/Bzip2Decompressor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/nativeio/NativeIO.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/nativeio/errno_enum.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/nativeio/file_descriptor.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/io/nativeio/SharedFileDescriptorFactory.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/net/unix/DomainSocket.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/net/unix/DomainSocketWatcher.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/security/JniBasedUnixGroupsMapping.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/security/JniBasedUnixGroupsNetgroupMapping.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/security/hadoop_group_info.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/security/hadoop_user_info.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/util/NativeCodeLoader.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/util/NativeCrc32.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/util/bulk_crc32.c.o"
  "CMakeFiles/hadoop.dir/main/native/src/org/apache/hadoop/util/bulk_crc32_x86.c.o"
  "target/usr/local/lib/libhadoop.pdb"
  "target/usr/local/lib/libhadoop.so"
  "target/usr/local/lib/libhadoop.so.1.0.0"
)

# Per-language clean rules from dependency scanning.
foreach(lang C)
  include(CMakeFiles/hadoop.dir/cmake_clean_${lang}.cmake OPTIONAL)
endforeach()
